==> foundation-ui-components-1.22.0.tgz: package/src/common/text-strip/NsTextStrip.tsx <==
/**
 * NsTextStrip.tsx
 * @description NsTextStrip component for scrolling text CTA
 */

import React from 'react';

import { ColorUtils, styled } from '@nuskin/foundation-theme';

import { NsLink } from '../link';
import { NsTypography } from '../typography';
import { NsTextStripProps } from './types.d';

const { getGenomeColor } = ColorUtils;

const StyledHeader = styled(NsLink)`
    background: ${({ theme }) => getGenomeColor(theme, 'N20')};
    min-height: 60px;
    padding: 4px 12px;
    a {
        text-decoration: underline;
        font-weight: 600;
    }
    .text-strip-title {
        max-width: 90%;
        overflow: hidden;
        text-overflow: ellipsis;
    }
    .text-strip-description {
        max-width: 90%;
        overflow: hidden;
        text-overflow: ellipsis;
    }
`;

const NsTextStrip = (props: NsTextStripProps) => {
    const { alignment = 'center', description, link, className = '' } = props;

    return (
        <StyledHeader
            href={link?.href ?? ''}
            className={`${className} items-${alignment} justify-center min-h-16 flex flex-col gap-1`}
        >
            {link?.title ? (
                <NsTypography weight="bold" variant="label-m" className="text-strip-title whitespace-nowrapd" noSpacing>
                    <span title={link?.title}>{link?.title}</span>
                </NsTypography>
            ) : null}
            {description ? (
                <NsTypography className="text-strip-description whitespace-nowrap" variant="body-m" noSpacing>
                    <span title={description}>{description}</span>
                </NsTypography>
            ) : null}
        </StyledHeader>
    );
};

export default NsTextStrip;

==> foundation-ui-components-1.22.3.tgz: package/src/common/text-strip/NsTextStrip.tsx <==
/**
 * NsTextStrip.tsx
 * @description NsTextStrip component for scrolling text CTA
 */

import React from 'react';

import {
    ColorUtils,
    styled,
} from '@nuskin/foundation-theme';

import { NsLink } from '../link';
import { NsTypography } from '../typography';
import { NsTextStripProps } from './types.d';

const { getGenomeColor } = ColorUtils;

const StyledHeader = styled(NsLink)`
    background: ${({ theme }) => getGenomeColor(theme, 'N20')};
    min-height: 60px;
    padding: 4px 12px;
    a {
        text-decoration: underline;
        font-weight: 600;
    }
    .text-strip-title {
        max-width: 90%;
        overflow: hidden;
        text-overflow: ellipsis;
    }
    .text-strip-description {
        max-width: 90%;
        overflow: hidden;
        text-overflow: ellipsis;
    }
`;

const NsTextStrip = (props: NsTextStripProps) => {
    const { alignment = 'center', description, link, className = '' } = props;

    return (
        <StyledHeader
            href={link?.href ?? ''}
            className={`${className} items-${alignment} justify-center min-h-16 flex flex-col gap-1`}
        >
            {link?.title ? (
                <NsTypography weight="bold" variant="label-m" className="text-strip-title whitespace-nowrap" noSpacing>
                    <span title={link?.title}>{link?.title}</span>
                </NsTypography>
            ) : null}
            {description ? (
                <NsTypography className="text-strip-description whitespace-nowrap" variant="body-m" noSpacing>
                    <span title={description}>{description}</span>
                </NsTypography>
            ) : null}
        </StyledHeader>
    );
};

export default NsTextStrip;
